| Title: | Names Given to Babies in Ontario Between 1917 and 2018 |
|---|---|
| Description: | A database containing the names of the babies born in Ontario between 1917 and 2018. Counts of fewer than 5 names were suppressed for privacy. |
| Authors: | Marc-Andre Desautels [aut, cre] |
| Maintainer: | Marc-Andre Desautels <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-05-18 10:39:33 UTC |
| Source: | https://github.com/desautm/onbabynames |
A database containing the first names of babies born in Ontario between 1917 and 2018. Counts of fewer than 5 names were suppressed for privacy.
onbabynamesonbabynames
A database containing 161 703 lines and 4 columns:
Year
F for female and M for male
Name
Frequency
library(dplyr) # The five most popular girls names in Ontario in 2018 onbabynames %>% filter(year == 2018 & sex == "F") %>% arrange(desc(n)) %>% head(5) library(ggplot2) # The popularity of the five most popular girls names in Ontario in 2018 # between 1917 and 2018 girls2018 <- onbabynames %>% filter(year == 2018 & sex == "F") %>% arrange(desc(n)) %>% select(name) %>% head(5) onbabynames %>% filter(name %in% girls2018$name) %>% ggplot(aes(x = year, y = n, color = name)) + geom_line()library(dplyr) # The five most popular girls names in Ontario in 2018 onbabynames %>% filter(year == 2018 & sex == "F") %>% arrange(desc(n)) %>% head(5) library(ggplot2) # The popularity of the five most popular girls names in Ontario in 2018 # between 1917 and 2018 girls2018 <- onbabynames %>% filter(year == 2018 & sex == "F") %>% arrange(desc(n)) %>% select(name) %>% head(5) onbabynames %>% filter(name %in% girls2018$name) %>% ggplot(aes(x = year, y = n, color = name)) + geom_line()